@@ -69,7 +69,7 @@ class HDF4FileHandler(BaseFileHandler):
     def _collect_attrs(self, name, attrs):
         for key, value in attrs.items():
             value = np.squeeze(value)
-            if issubclass(value.dtype.type, (np.string_, np.unicode_)) and not value.shape:
+            if issubclass(value.dtype.type, (np.bytes_, np.str_)) and not value.shape:
                 value = value.item()  # convert to scalar
                 if not isinstance(value, str):
                     # python 3 - was scalar numpy array of bytes
