@@ -61,14 +61,22 @@ argument upon Scene creation::
                         reader_kwargs={'calib_mode': 'GSICS'})
     scene.load(['VIS006', 'IR_108'])
 
-Furthermore, it is possible to specify external calibration coefficients
-for the conversion from counts to radiances. External coefficients take
-precedence over internal coefficients, but you can also mix internal and
-external coefficients: If external calibration coefficients are specified
-for only a subset of channels, the remaining channels will be calibrated
-using the chosen file-internal coefficients (nominal or GSICS).
+In addition, two other calibration methods are available:
+
+1. It is possible to specify external calibration coefficients for the
+   conversion from counts to radiances. External coefficients take
+   precedence over internal coefficients and over the Meirink
+   coefficients, but you can also mix internal and external coefficients:
+   If external calibration coefficients are specified for only a subset
+   of channels, the remaining channels will be calibrated using the
+   chosen file-internal coefficients (nominal or GSICS).  Calibration
+   coefficients must be specified in [mW m-2 sr-1 (cm-1)-1].
+
+2. The calibration mode ``meirink-2023`` uses coefficients based on an
+   intercalibration with Aqua-MODIS for the visible channels, as found in
+   `Inter-calibration of polar imager solar channels using SEVIRI`_
+   (2013) by J. F. Meirink, R. A. Roebeling, and P. Stammes.
 
-Calibration coefficients must be specified in [mW m-2 sr-1 (cm-1)-1].
 
 In the following example we use external calibration coefficients for the
 ``VIS006`` & ``IR_108`` channels, and nominal coefficients for the
@@ -93,6 +101,15 @@ In the next example we use external calibration coefficients for the
                                        'ext_calib_coefs': coefs})
     scene.load(['VIS006', 'VIS008', 'IR_108', 'IR_120'])
 
+In the next example we use the mode ``meirink-2023`` calibration
+coefficients for all visible channels and nominal coefficients for the
+rest::
+
+    scene = satpy.Scene(filenames,
+                        reader='seviri_l1b_...',
+                        reader_kwargs={'calib_mode': 'meirink-2023'})
+    scene.load(['VIS006', 'VIS008', 'IR_016'])
+
 
 Calibration to reflectance
 ^^^^^^^^^^^^^^^^^^^^^^^^^^
@@ -122,7 +139,7 @@ The SEVIRI L1.5 readers provide the following metadata:
 
 * The ``orbital_parameters`` attribute provides the nominal and actual satellite
   position, as well as the projection centre. See the `Metadata` section in
-  the :doc:`../readers` chapter for more information.
+  the :doc:`../reading` chapter for more information.
 
 * The ``acq_time`` coordinate provides the mean acquisition time for each
   scanline. Use a ``MultiIndex`` to enable selection by acquisition time:
@@ -163,10 +180,14 @@ References:
 .. _Radiometric Calibration of MSG SEVIRI Level 1.5 Image Data in Equivalent Spectral Blackbody Radiance:
     https://www-cdn.eumetsat.int/files/2020-04/pdf_ten_msg_seviri_rad_calib.pdf
 
+.. _Inter-calibration of polar imager solar channels using SEVIRI:
+   http://dx.doi.org/10.5194/amt-6-2495-2013
+
 """
+from __future__ import annotations
 
 import warnings
-from datetime import timedelta
+from datetime import datetime, timedelta
 
 import dask.array as da
 import numpy as np
@@ -353,6 +374,87 @@ CALIB[324] = {'HRV': {'F': 79.0035},
                          'ALPHA': 0.9981,
                          'BETA': 0.5635}}
 
+# Calibration coefficients from Meirink, J.F., R.A. Roebeling and P. Stammes, 2013:
+# Inter-calibration of polar imager solar channels using SEVIRI, Atm. Meas. Tech., 6,
+# 2495-2508, doi:10.5194/amt-6-2495-2013
+#
+# The coeffients in the 2023 entry have been obtained from the webpage
+# https://msgcpp.knmi.nl/solar-channel-calibration.html on 2023-10-11.
+#
+# The coefficients are stored in pairs of A, B (see function `get_meirink_slope`) where the
+# units of A are µW m-2 sr-1 (cm-1)-1 and those of B are µW m-2 sr-1 (cm-1)-1 (86400 s)-1
+#
+# To obtain the slope for the calibration, one should use the routine get_seviri_meirink_slope
+
+# Epoch for the MEIRINK re-calibration
+MEIRINK_EPOCH = datetime(2000, 1, 1)
+
+MEIRINK_COEFS: dict[str, dict[int, dict[str, tuple[float, float]]]] = {}
+MEIRINK_COEFS['2023'] = {}
+
+# Meteosat-8
+
+MEIRINK_COEFS['2023'][321] = {'VIS006': (24.346, 0.3739),
+                              'VIS008': (30.989, 0.3111),
+                              'IR_016': (22.869, 0.0065)
+                              }
+
+# Meteosat-9
+
+MEIRINK_COEFS['2023'][322] = {'VIS006': (21.026, 0.2556),
+                              'VIS008': (26.875, 0.1835),
+                              'IR_016': (21.394, 0.0498)
+                              }
+
+# Meteosat-10
+
+MEIRINK_COEFS['2023'][323] = {'VIS006': (19.829, 0.5856),
+                              'VIS008': (25.284, 0.6787),
+                              'IR_016': (23.066, -0.0286)
+                              }
+
+# Meteosat-11
+
+MEIRINK_COEFS['2023'][324] = {'VIS006': (20.515, 0.3600),
+                              'VIS008': (25.803, 0.4844),
+                              'IR_016': (22.354, -0.0187)
+                              }
+
+
+def get_meirink_slope(meirink_coefs, acquisition_time):
+    """Compute the slope for the visible channel calibration according to Meirink 2013.
+
+    S = A + B * 1.e-3* Day
+
+    S is here in µW m-2 sr-1 (cm-1)-1
+
+    EUMETSAT calibration is given in mW m-2 sr-1 (cm-1)-1, so an extra factor of 1/1000 must
+    be applied.
+    """
+    A = meirink_coefs[0]
+    B = meirink_coefs[1]
+    delta_t = (acquisition_time - MEIRINK_EPOCH).total_seconds()
+    S = A + B * delta_t / (3600*24) / 1000.
+    return S/1000
+
+
+def should_apply_meirink(calib_mode, channel_name):
+    """Decide whether to use the Meirink calibration coefficients."""
+    return "MEIRINK" in calib_mode and channel_name in ['VIS006', 'VIS008', 'IR_016']
+
+
+class MeirinkCalibrationHandler:
+    """Re-calibration of the SEVIRI visible channels slope (see Meirink 2013)."""
+
+    def __init__(self, calib_mode):
+        """Initialize the calibration handler."""
+        self.coefs = MEIRINK_COEFS[calib_mode.split('-')[1]]
+
+    def get_slope(self, platform, channel, time):
+        """Return the slope using the provided calibration coefficients."""
+        coefs = self.coefs[platform][channel]
+        return get_meirink_slope(coefs, time)
+
 
 def get_cds_time(days, msecs):
     """Compute timestamp given the days since epoch and milliseconds of the day.
@@ -566,7 +668,7 @@ class SEVIRICalibrationHandler:
             scan_time=self._scan_time
         )
 
-        valid_modes = ('NOMINAL', 'GSICS')
+        valid_modes = ('NOMINAL', 'GSICS', 'MEIRINK-2023')
         if self._calib_mode not in valid_modes:
             raise ValueError(
                 'Invalid calibration mode: {}. Choose one of {}'.format(
@@ -622,6 +724,10 @@ class SEVIRICalibrationHandler:
                 internal_gain = gsics_gain
                 internal_offset = gsics_offset
 
+        if should_apply_meirink(self._calib_mode, self._channel_name):
+            meirink = MeirinkCalibrationHandler(calib_mode=self._calib_mode)
+            internal_gain = meirink.get_slope(self._platform_id, self._channel_name, self._scan_time)
+
         # Override with external coefficients, if any.
         gain = coefs['EXTERNAL'].get('gain', internal_gain)
         offset = coefs['EXTERNAL'].get('offset', internal_offset)
