@@ -29,11 +29,11 @@ import dask.array as da
 import numpy as np
 import xarray as xr
 
-from satpy import CHUNK_SIZE
 from satpy.readers._geos_area import get_area_definition, get_geos_area_naming
 from satpy.readers.eum_base import get_service_mode
 from satpy.readers.file_handlers import BaseFileHandler
 from satpy.readers.seviri_base import PLATFORM_DICT, REPEAT_CYCLE_DURATION, calculate_area_extent
+from satpy.utils import get_legacy_chunk_size
 
 try:
     import eccodes as ec
@@ -41,6 +41,7 @@ except ImportError:
     raise ImportError(
         "Missing eccodes-python and/or eccodes C-library installation. Use conda to install eccodes")
 
+CHUNK_SIZE = get_legacy_chunk_size()
 logger = logging.getLogger(__name__)
 
 
