@@ -14,7 +14,6 @@
 # You should have received a copy of the GNU General Public License along with
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
 """Tests for spectral correction compositors."""
-import warnings
 
 import dask.array as da
 import numpy as np
@@ -66,8 +65,24 @@ class TestSpectralComposites:
         data = res.compute()
         np.testing.assert_allclose(data, 0.23)
 
-    def test_ndvi_hybrid_green(self):
-        """Test NDVI-scaled hybrid green correction of 'green' band."""
+    def test_green_corrector(self):
+        """Test the deprecated class for green corrections."""
+        comp = GreenCorrector('blended_channel', fractions=(0.85, 0.15), prerequisites=(0.51, 0.85),
+                              standard_name='toa_bidirectional_reflectance')
+        res = comp((self.c01, self.c03))
+        assert isinstance(res, xr.DataArray)
+        assert isinstance(res.data, da.Array)
+        assert res.attrs['name'] == 'blended_channel'
+        assert res.attrs['standard_name'] == 'toa_bidirectional_reflectance'
+        data = res.compute()
+        np.testing.assert_allclose(data, 0.23)
+
+
+class TestNdviHybridGreenCompositor:
+    """Test NDVI-weighted hybrid green correction of green band."""
+
+    def setup_method(self):
+        """Initialize channels."""
         self.c01 = xr.DataArray(da.from_array([[0.25, 0.30], [0.20, 0.30]], chunks=25),
                                 dims=('y', 'x'), attrs={'name': 'C02'})
         self.c02 = xr.DataArray(da.from_array([[0.25, 0.30], [0.25, 0.35]], chunks=25),
@@ -75,9 +90,12 @@ class TestSpectralComposites:
         self.c03 = xr.DataArray(da.from_array([[0.35, 0.35], [0.28, 0.65]], chunks=25),
                                 dims=('y', 'x'), attrs={'name': 'C04'})
 
+    def test_ndvi_hybrid_green(self):
+        """Test General functionality with linear scaling from ndvi to blend fraction."""
         comp = NDVIHybridGreen('ndvi_hybrid_green', limits=(0.15, 0.05), prerequisites=(0.51, 0.65, 0.85),
                                standard_name='toa_bidirectional_reflectance')
 
+        # Test General functionality with linear strength (=1.0)
         res = comp((self.c01, self.c02, self.c03))
         assert isinstance(res, xr.DataArray)
         assert isinstance(res.data, da.Array)
@@ -86,16 +104,16 @@ class TestSpectralComposites:
         data = res.values
         np.testing.assert_array_almost_equal(data, np.array([[0.2633, 0.3071], [0.2115, 0.3420]]), decimal=4)
 
-    def test_green_corrector(self):
-        """Test the deprecated class for green corrections."""
-        with warnings.catch_warnings():
-            warnings.filterwarnings("ignore", category=UserWarning, message=r'.*deprecated.*')
-            comp = GreenCorrector('blended_channel', fractions=(0.85, 0.15), prerequisites=(0.51, 0.85),
-                                  standard_name='toa_bidirectional_reflectance')
-        res = comp((self.c01, self.c03))
-        assert isinstance(res, xr.DataArray)
-        assert isinstance(res.data, da.Array)
-        assert res.attrs['name'] == 'blended_channel'
-        assert res.attrs['standard_name'] == 'toa_bidirectional_reflectance'
-        data = res.compute()
-        np.testing.assert_allclose(data, 0.23)
+    def test_nonliniear_scaling(self):
+        """Test non-linear scaling using `strength` term."""
+        comp = NDVIHybridGreen('ndvi_hybrid_green', limits=(0.15, 0.05), strength=2.0, prerequisites=(0.51, 0.65, 0.85),
+                               standard_name='toa_bidirectional_reflectance')
+
+        res = comp((self.c01, self.c02, self.c03))
+        np.testing.assert_array_almost_equal(res.values, np.array([[0.2646, 0.3075], [0.2120, 0.3471]]), decimal=4)
+
+    def test_invalid_strength(self):
+        """Test using invalid `strength` term for non-linear scaling."""
+        with pytest.raises(ValueError):
+            _ = NDVIHybridGreen('ndvi_hybrid_green', strength=0.0, prerequisites=(0.51, 0.65, 0.85),
+                                standard_name='toa_bidirectional_reflectance')
