@@ -149,19 +149,13 @@ class TestEnhancementStretch:
         from trollimage.colormap import brbg
 
         from satpy.enhancements import colorize
-        expected = np.array([[
-            [np.nan, 3.29409498e-01, 3.29409498e-01,
-             4.35952940e-06, 4.35952940e-06],
-            [4.35952940e-06, 4.35952940e-06, 4.35952940e-06,
-             4.35952940e-06, 4.35952940e-06]],
-            [[np.nan, 1.88249866e-01, 1.88249866e-01,
-              2.35302110e-01, 2.35302110e-01],
-             [2.35302110e-01, 2.35302110e-01, 2.35302110e-01,
-              2.35302110e-01, 2.35302110e-01]],
-            [[np.nan, 1.96102817e-02, 1.96102817e-02,
-              1.88238767e-01, 1.88238767e-01],
-             [1.88238767e-01, 1.88238767e-01, 1.88238767e-01,
-              1.88238767e-01, 1.88238767e-01]]])
+        expected = np.array([
+            [[np.nan, 3.29411723e-01, 3.29411723e-01, 3.21825881e-08, 3.21825881e-08],
+             [3.21825881e-08, 3.21825881e-08, 3.21825881e-08, 3.21825881e-08, 3.21825881e-08]],
+            [[np.nan, 1.88235327e-01, 1.88235327e-01, 2.35294109e-01, 2.35294109e-01],
+             [2.35294109e-01, 2.35294109e-01, 2.35294109e-01, 2.35294109e-01, 2.35294109e-01]],
+            [[np.nan, 1.96078164e-02, 1.96078164e-02, 1.88235281e-01, 1.88235281e-01],
+             [1.88235281e-01, 1.88235281e-01, 1.88235281e-01, 1.88235281e-01, 1.88235281e-01]]])
         run_and_check_enhancement(colorize, self.ch1, expected, palettes=brbg)
 
     def test_palettize(self):
