@@ -40,16 +40,16 @@ CHANNELS_BY_RESOLUTION = {500: ["C02"],
 RESOLUTION_LIST = [500, 1000, 2000, 4000]
 
 AREA_EXTENTS_BY_RESOLUTION = {'FY4A': {
-    500: (-5495271.006002, -5496021.008869, -5493270.998357, -5495521.006957),
-    1000: (-5494521.070252, -5496021.076004, -5490521.054912, -5495021.072169),
-    2000: (-5493021.198696, -5496021.210274, -5485021.167823, -5494021.202556),
-    4000: (-5490021.187119, -5496021.210274, -5474021.125371, -5492021.194837)
+    500: (-5496021.008869, 5495021.005046, -5493520.999312, 5496021.008869),
+    1000: (-5496021.076004, 5494021.068334, -5491021.05683, 5496021.076004),
+    2000: (-5496021.210274, 5492021.194837, -5486021.171682, 5496021.210274),
+    4000: (-5496021.210274, 5488021.1794, -5476021.13309, 5496021.210274)
 },
     'FY4B': {
-        500: (-5495271.006002, -5496021.008869, -5493270.998357, -5495521.006957),
-        1000: (-5494521.070252, -5496021.076004, -5490521.054912, -5495021.072169),
-        2000: (-5493021.198696, -5496021.210274, -5485021.167823, -5494021.202556),
-        4000: (-5490021.187119, -5496021.210274, -5474021.125371, -5492021.194837)
+        500: (-5496021.008869, 5495021.005046, -5493520.999312, 5496021.008869),
+        1000: (-5496021.076004, 5494021.068334, -5491021.05683, 5496021.076004),
+        2000: (-5496021.210274, 5492021.194837, -5486021.171682, 5496021.210274),
+        4000: (-5496021.210274, 5488021.1794, -5476021.13309, 5496021.210274)
     }}
 
 
@@ -201,6 +201,8 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
             '/attr/RegWidth': np.array(5.0),
             '/attr/Begin Line Number': np.array(0),
             '/attr/End Line Number': np.array(1),
+            '/attr/Begin Pixel Number': np.array(0),
+            '/attr/End Pixel Number': np.array(1),
             '/attr/Observing Beginning Date': '2019-06-03', '/attr/Observing Beginning Time': '00:30:01.807',
             '/attr/Observing Ending Date': '2019-06-03', '/attr/Observing Ending Time': '00:34:07.572',
             '/attr/Satellite Name': 'FY4A', '/attr/Sensor Identification Code': 'AGRI', '/attr/Sensor Name': 'AGRI',
