@@ -21,6 +21,7 @@ import logging
 import typing
 import unittest
 import warnings
+from math import sqrt
 from unittest import mock
 
 import dask.array as da
@@ -44,182 +45,100 @@ from satpy.utils import (
 # - caplog
 
 
-class TestUtils(unittest.TestCase):
-    """Testing utils."""
+class TestGeoUtils:
+    """Testing geo-related utility functions."""
 
-    def test_lonlat2xyz(self):
+    @pytest.mark.parametrize(
+        ("lonlat", "xyz"),
+        [
+            ((0, 0), (1, 0, 0)),
+            ((90, 0), (0, 1, 0)),
+            ((0, 90), (0, 0, 1)),
+            ((180, 0), (-1, 0, 0)),
+            ((-90, 0), (0, -1, 0)),
+            ((0, -90), (0, 0, -1)),
+            ((0, 45), (sqrt(2) / 2, 0, sqrt(2) / 2)),
+            ((0, 60), (sqrt(1) / 2, 0, sqrt(3) / 2)),
+        ],
+    )
+    def test_lonlat2xyz(self, lonlat, xyz):
         """Test the lonlat2xyz function."""
-        x__, y__, z__ = lonlat2xyz(0, 0)
-        self.assertAlmostEqual(x__, 1)
-        self.assertAlmostEqual(y__, 0)
-        self.assertAlmostEqual(z__, 0)
+        x__, y__, z__ = lonlat2xyz(*lonlat)
+        assert x__ == pytest.approx(xyz[0])
+        assert y__ == pytest.approx(xyz[1])
+        assert z__ == pytest.approx(xyz[2])
 
-        x__, y__, z__ = lonlat2xyz(90, 0)
-        self.assertAlmostEqual(x__, 0)
-        self.assertAlmostEqual(y__, 1)
-        self.assertAlmostEqual(z__, 0)
+    @pytest.mark.parametrize(
+        ("azizen", "xyz"),
+        [
+            ((0, 0), (0, 0, 1)),
+            ((90, 0), (0, 0, 1)),
+            ((0, 90), (0, 1, 0)),
+            ((180, 0), (0, 0, 1)),
+            ((-90, 0), (0, 0, 1)),
+            ((0, -90), (0, -1, 0)),
+            ((90, 90), (1, 0, 0)),
+            ((-90, 90), (-1, 0, 0)),
+            ((180, 90), (0, -1, 0)),
+            ((0, -90), (0, -1, 0)),
+            ((0, 45), (0, sqrt(2) / 2, sqrt(2) / 2)),
+            ((0, 60), (0, sqrt(3) / 2, sqrt(1) / 2)),
+        ],
+    )
+    def test_angle2xyz(self, azizen, xyz):
+        """Test the angle2xyz function."""
+        x__, y__, z__ = angle2xyz(*azizen)
+        assert x__ == pytest.approx(xyz[0])
+        assert y__ == pytest.approx(xyz[1])
+        assert z__ == pytest.approx(xyz[2])
 
-        x__, y__, z__ = lonlat2xyz(0, 90)
-        self.assertAlmostEqual(x__, 0)
-        self.assertAlmostEqual(y__, 0)
-        self.assertAlmostEqual(z__, 1)
-
-        x__, y__, z__ = lonlat2xyz(180, 0)
-        self.assertAlmostEqual(x__, -1)
-        self.assertAlmostEqual(y__, 0)
-        self.assertAlmostEqual(z__, 0)
-
-        x__, y__, z__ = lonlat2xyz(-90, 0)
-        self.assertAlmostEqual(x__, 0)
-        self.assertAlmostEqual(y__, -1)
-        self.assertAlmostEqual(z__, 0)
-
-        x__, y__, z__ = lonlat2xyz(0, -90)
-        self.assertAlmostEqual(x__, 0)
-        self.assertAlmostEqual(y__, 0)
-        self.assertAlmostEqual(z__, -1)
-
-        x__, y__, z__ = lonlat2xyz(0, 45)
-        self.assertAlmostEqual(x__, np.sqrt(2) / 2)
-        self.assertAlmostEqual(y__, 0)
-        self.assertAlmostEqual(z__, np.sqrt(2) / 2)
-
-        x__, y__, z__ = lonlat2xyz(0, 60)
-        self.assertAlmostEqual(x__, np.sqrt(1) / 2)
-        self.assertAlmostEqual(y__, 0)
-        self.assertAlmostEqual(z__, np.sqrt(3) / 2)
-
-    def test_angle2xyz(self):
-        """Test the lonlat2xyz function."""
-        x__, y__, z__ = angle2xyz(0, 0)
-        self.assertAlmostEqual(x__, 0)
-        self.assertAlmostEqual(y__, 0)
-        self.assertAlmostEqual(z__, 1)
-
-        x__, y__, z__ = angle2xyz(90, 0)
-        self.assertAlmostEqual(x__, 0)
-        self.assertAlmostEqual(y__, 0)
-        self.assertAlmostEqual(z__, 1)
-
-        x__, y__, z__ = angle2xyz(0, 90)
-        self.assertAlmostEqual(x__, 0)
-        self.assertAlmostEqual(y__, 1)
-        self.assertAlmostEqual(z__, 0)
-
-        x__, y__, z__ = angle2xyz(180, 0)
-        self.assertAlmostEqual(x__, 0)
-        self.assertAlmostEqual(y__, 0)
-        self.assertAlmostEqual(z__, 1)
-
-        x__, y__, z__ = angle2xyz(-90, 0)
-        self.assertAlmostEqual(x__, 0)
-        self.assertAlmostEqual(y__, 0)
-        self.assertAlmostEqual(z__, 1)
-
-        x__, y__, z__ = angle2xyz(0, -90)
-        self.assertAlmostEqual(x__, 0)
-        self.assertAlmostEqual(y__, -1)
-        self.assertAlmostEqual(z__, 0)
-
-        x__, y__, z__ = angle2xyz(90, 90)
-        self.assertAlmostEqual(x__, 1)
-        self.assertAlmostEqual(y__, 0)
-        self.assertAlmostEqual(z__, 0)
-
-        x__, y__, z__ = angle2xyz(-90, 90)
-        self.assertAlmostEqual(x__, -1)
-        self.assertAlmostEqual(y__, 0)
-        self.assertAlmostEqual(z__, 0)
-
-        x__, y__, z__ = angle2xyz(180, 90)
-        self.assertAlmostEqual(x__, 0)
-        self.assertAlmostEqual(y__, -1)
-        self.assertAlmostEqual(z__, 0)
-
-        x__, y__, z__ = angle2xyz(0, -90)
-        self.assertAlmostEqual(x__, 0)
-        self.assertAlmostEqual(y__, -1)
-        self.assertAlmostEqual(z__, 0)
-
-        x__, y__, z__ = angle2xyz(0, 45)
-        self.assertAlmostEqual(x__, 0)
-        self.assertAlmostEqual(y__, np.sqrt(2) / 2)
-        self.assertAlmostEqual(z__, np.sqrt(2) / 2)
-
-        x__, y__, z__ = angle2xyz(0, 60)
-        self.assertAlmostEqual(x__, 0)
-        self.assertAlmostEqual(y__, np.sqrt(3) / 2)
-        self.assertAlmostEqual(z__, np.sqrt(1) / 2)
-
-    def test_xyz2lonlat(self):
+    @pytest.mark.parametrize(
+        ("xyz", "asin", "lonlat"),
+        [
+            ((1, 0, 0), False, (0, 0)),
+            ((0, 1, 0), False, (90, 0)),
+            ((0, 0, 1), True, (0, 90)),
+            ((0, 0, 1), False, (0, 90)),
+            ((sqrt(2) / 2, sqrt(2) / 2, 0), False, (45, 0)),
+        ],
+    )
+    def test_xyz2lonlat(self, xyz, asin, lonlat):
         """Test xyz2lonlat."""
-        lon, lat = xyz2lonlat(1, 0, 0)
-        self.assertAlmostEqual(lon, 0)
-        self.assertAlmostEqual(lat, 0)
+        lon, lat = xyz2lonlat(*xyz, asin=asin)
+        assert lon == pytest.approx(lonlat[0])
+        assert lat == pytest.approx(lonlat[1])
 
-        lon, lat = xyz2lonlat(0, 1, 0)
-        self.assertAlmostEqual(lon, 90)
-        self.assertAlmostEqual(lat, 0)
-
-        lon, lat = xyz2lonlat(0, 0, 1, asin=True)
-        self.assertAlmostEqual(lon, 0)
-        self.assertAlmostEqual(lat, 90)
-
-        lon, lat = xyz2lonlat(0, 0, 1)
-        self.assertAlmostEqual(lon, 0)
-        self.assertAlmostEqual(lat, 90)
-
-        lon, lat = xyz2lonlat(np.sqrt(2) / 2, np.sqrt(2) / 2, 0)
-        self.assertAlmostEqual(lon, 45)
-        self.assertAlmostEqual(lat, 0)
-
-    def test_xyz2angle(self):
+    @pytest.mark.parametrize(
+        ("xyz", "acos", "azizen"),
+        [
+            ((1, 0, 0), False, (90, 90)),
+            ((0, 1, 0), False, (0, 90)),
+            ((0, 0, 1), False, (0, 0)),
+            ((0, 0, 1), True, (0, 0)),
+            ((sqrt(2) / 2, sqrt(2) / 2, 0), False, (45, 90)),
+            ((-1, 0, 0), False, (-90, 90)),
+            ((0, -1, 0), False, (180, 90)),
+        ],
+    )
+    def test_xyz2angle(self, xyz, acos, azizen):
         """Test xyz2angle."""
-        azi, zen = xyz2angle(1, 0, 0)
-        self.assertAlmostEqual(azi, 90)
-        self.assertAlmostEqual(zen, 90)
+        azi, zen = xyz2angle(*xyz, acos=acos)
+        assert azi == pytest.approx(azi)
+        assert zen == pytest.approx(zen)
 
-        azi, zen = xyz2angle(0, 1, 0)
-        self.assertAlmostEqual(azi, 0)
-        self.assertAlmostEqual(zen, 90)
-
-        azi, zen = xyz2angle(0, 0, 1)
-        self.assertAlmostEqual(azi, 0)
-        self.assertAlmostEqual(zen, 0)
-
-        azi, zen = xyz2angle(0, 0, 1, acos=True)
-        self.assertAlmostEqual(azi, 0)
-        self.assertAlmostEqual(zen, 0)
-
-        azi, zen = xyz2angle(np.sqrt(2) / 2, np.sqrt(2) / 2, 0)
-        self.assertAlmostEqual(azi, 45)
-        self.assertAlmostEqual(zen, 90)
-
-        azi, zen = xyz2angle(-1, 0, 0)
-        self.assertAlmostEqual(azi, -90)
-        self.assertAlmostEqual(zen, 90)
-
-        azi, zen = xyz2angle(0, -1, 0)
-        self.assertAlmostEqual(azi, 180)
-        self.assertAlmostEqual(zen, 90)
-
-    def test_proj_units_to_meters(self):
+    @pytest.mark.parametrize(
+        ("prj", "exp_prj"),
+        [
+            ("+asd=123123123123", "+asd=123123123123"),
+            ("+a=6378.137", "+a=6378137.000"),
+            ("+a=6378.137 +units=km", "+a=6378137.000"),
+            ("+a=6378.137 +b=6378.137", "+a=6378137.000 +b=6378137.000"),
+            ("+a=6378.137 +b=6378.137 +h=35785.863", "+a=6378137.000 +b=6378137.000 +h=35785863.000"),
+        ],
+    )
+    def test_proj_units_to_meters(self, prj, exp_prj):
         """Test proj units to meters conversion."""
-        prj = '+asd=123123123123'
-        res = proj_units_to_meters(prj)
-        self.assertEqual(res, prj)
-        prj = '+a=6378.137'
-        res = proj_units_to_meters(prj)
-        self.assertEqual(res, '+a=6378137.000')
-        prj = '+a=6378.137 +units=km'
-        res = proj_units_to_meters(prj)
-        self.assertEqual(res, '+a=6378137.000')
-        prj = '+a=6378.137 +b=6378.137'
-        res = proj_units_to_meters(prj)
-        self.assertEqual(res, '+a=6378137.000 +b=6378137.000')
-        prj = '+a=6378.137 +b=6378.137 +h=35785.863'
-        res = proj_units_to_meters(prj)
-        self.assertEqual(res, '+a=6378137.000 +b=6378137.000 +h=35785863.000')
+        assert proj_units_to_meters(prj) == exp_prj
 
 
 class TestGetSatPos:
@@ -273,7 +192,7 @@ class TestGetSatPos:
         "attrs",
         (
                 {},
-                {'orbital_parameters':  {'projection_longitude': 1}},
+                {'orbital_parameters': {'projection_longitude': 1}},
                 {'satellite_altitude': 1}
         )
     )
@@ -288,16 +207,17 @@ class TestGetSatPos:
         import pyorbital.tlefile
 
         data_arr = xr.DataArray(
-                (),
-                attrs={
-                    "platform_name": "Meteosat-42",
-                    "sensor": "irives",
-                    "start_time": datetime.datetime(2031, 11, 20, 19, 18, 17)})
+            (),
+            attrs={
+                "platform_name": "Meteosat-42",
+                "sensor": "irives",
+                "start_time": datetime.datetime(2031, 11, 20, 19, 18, 17)
+            })
         with mock.patch("pyorbital.tlefile.read") as plr:
             plr.return_value = pyorbital.tlefile.Tle(
-                    "Meteosat-42",
-                    line1="1 40732U 15034A   22011.84285506  .00000004  00000+0  00000+0 0  9995",
-                    line2="2 40732   0.2533 325.0106 0000976 118.8734 330.4058  1.00272123 23817")
+                "Meteosat-42",
+                line1="1 40732U 15034A   22011.84285506  .00000004  00000+0  00000+0 0  9995",
+                line2="2 40732   0.2533 325.0106 0000976 118.8734 330.4058  1.00272123 23817")
             with caplog.at_level(logging.WARNING):
                 (lon, lat, alt) = get_satpos(data_arr, use_tle=True)
             assert "Orbital parameters missing from metadata" in caplog.text
@@ -319,13 +239,15 @@ def test_make_fake_scene():
 
     assert make_fake_scene({}).keys() == []
     sc = make_fake_scene({
-        "six": np.arange(25).reshape(5, 5)})
+        "six": np.arange(25).reshape(5, 5)
+    })
     assert len(sc.keys()) == 1
     assert sc.keys().pop()['name'] == "six"
     assert sc["six"].attrs["area"].shape == (5, 5)
     sc = make_fake_scene({
-        "seven": np.arange(3*7).reshape(3, 7),
-        "eight": np.arange(3*8).reshape(3, 8)},
+        "seven": np.arange(3 * 7).reshape(3, 7),
+        "eight": np.arange(3 * 8).reshape(3, 8)
+    },
         daskify=True,
         area=False,
         common_attrs={"repetency": "fourteen hundred per centimetre"})
@@ -335,9 +257,10 @@ def test_make_fake_scene():
     assert isinstance(sc["seven"].data, da.Array)
     sc = make_fake_scene({
         "nine": xr.DataArray(
-            np.arange(2*9).reshape(2, 9),
+            np.arange(2 * 9).reshape(2, 9),
             dims=("y", "x"),
-            attrs={"please": "preserve", "answer": 42})},
+            attrs={"please": "preserve", "answer": 42})
+    },
         common_attrs={"bad words": "semprini bahnhof veerooster winterbanden"})
     assert sc["nine"].attrs.keys() >= {"please", "answer", "bad words", "area"}
 
@@ -376,6 +299,7 @@ def test_debug_on(caplog):
             DeprecationWarning,
             stacklevel=2
         )
+
     warnings.filterwarnings("ignore", category=DeprecationWarning)
     debug_on(False)
     filts_before = warnings.filters.copy()
@@ -497,6 +421,53 @@ def test_get_legacy_chunk_size():
         assert get_legacy_chunk_size() == 2048
 
 
+@pytest.mark.parametrize(
+    ("chunks", "shape", "previous_chunks", "lr_mult", "chunk_dtype", "exp_result"),
+    [
+        # 1km swath
+        (("auto", -1), (1000, 3200), (40, 40), (4, 4), np.float32, (160, -1)),
+        # 5km swath
+        (("auto", -1), (1000 // 5, 3200 // 5), (40, 40), (20, 20), np.float32, (160 / 5, -1)),
+        # 250m swath
+        (("auto", -1), (1000 * 4, 3200 * 4), (40, 40), (1, 1), np.float32, (160 * 4, -1)),
+        # 1km area (ABI chunk 226):
+        (("auto", "auto"), (21696 // 2, 21696 // 2), (226*4, 226*4), (2, 2), np.float32, (1356, 1356)),
+        # 1km area (64-bit)
+        (("auto", "auto"), (21696 // 2, 21696 // 2), (226*4, 226*4), (2, 2), np.float64, (904, 904)),
+        # 3km area
+        (("auto", "auto"), (21696 // 3, 21696 // 3), (226*4, 226*4), (6, 6), np.float32, (452, 452)),
+        # 500m area
+        (("auto", "auto"), (21696, 21696), (226*4, 226*4), (1, 1), np.float32, (1356 * 2, 1356 * 2)),
+        # 500m area (64-bit)
+        (("auto", "auto"), (21696, 21696), (226*4, 226*4), (1, 1), np.float64, (904 * 2, 904 * 2)),
+        # 250m swath with bands:
+        ((1, "auto", -1), (7, 1000 * 4, 3200 * 4), (1, 40, 40), (1, 1, 1), np.float32, (1, 160 * 4, -1)),
+        # lots of dimensions:
+        ((1, 1, "auto", -1), (1, 7, 1000, 3200), (1, 1, 40, 40), (1, 1, 1, 1), np.float32, (1, 1, 1000, -1)),
+    ],
+)
+def test_resolution_chunking(chunks, shape, previous_chunks, lr_mult, chunk_dtype, exp_result):
+    """Test normalize_low_res_chunks helper function."""
+    import dask.config
+
+    from satpy.utils import normalize_low_res_chunks
+
+    with dask.config.set({"array.chunk-size": "32MiB"}):
+        chunk_results = normalize_low_res_chunks(
+            chunks,
+            shape,
+            previous_chunks,
+            lr_mult,
+            chunk_dtype,
+        )
+    assert chunk_results == exp_result
+    for chunk_size in chunk_results:
+        assert isinstance(chunk_size[0], int) if isinstance(chunk_size, tuple) else isinstance(chunk_size, int)
+
+    # make sure the chunks are understandable by dask
+    da.zeros(shape, dtype=chunk_dtype, chunks=chunk_results)
+
+
 def test_convert_remote_files_to_fsspec_local_files():
     """Test convertion of remote files to fsspec objects.
 
@@ -615,19 +586,21 @@ def test_find_in_ancillary():
     """Test finding a dataset in ancillary variables."""
     from satpy.utils import find_in_ancillary
     index_finger = xr.DataArray(
-            data=np.arange(25).reshape(5, 5),
-            dims=("y", "x"),
-            attrs={"name": "index-finger"})
+        data=np.arange(25).reshape(5, 5),
+        dims=("y", "x"),
+        attrs={"name": "index-finger"})
     ring_finger = xr.DataArray(
-            data=np.arange(25).reshape(5, 5),
-            dims=("y", "x"),
-            attrs={"name": "ring-finger"})
+        data=np.arange(25).reshape(5, 5),
+        dims=("y", "x"),
+        attrs={"name": "ring-finger"})
 
     hand = xr.DataArray(
-            data=np.arange(25).reshape(5, 5),
-            dims=("y", "x"),
-            attrs={"name": "hand",
-                   "ancillary_variables": [index_finger, index_finger, ring_finger]})
+        data=np.arange(25).reshape(5, 5),
+        dims=("y", "x"),
+        attrs={
+            "name": "hand",
+            "ancillary_variables": [index_finger, index_finger, ring_finger]
+        })
 
     assert find_in_ancillary(hand, "ring-finger") is ring_finger
     with pytest.raises(
